@@ -163,7 +163,7 @@ decorator_save_info (TrackerExtractDecorator *decorator,
 	urn = tracker_decorator_info_get_urn (decorator_info);
 
 	tracker_resource_set_identifier (resource, urn);
-	tracker_resource_set_uri (resource, "nie:dataSource",
+	tracker_resource_add_uri (resource, "nie:dataSource",
 	        tracker_decorator_get_data_source (TRACKER_DECORATOR (decorator)));
 
 	return resource;
@@ -360,12 +360,16 @@ tracker_extract_decorator_finished (TrackerDecorator *decorator)
 {
 	TrackerExtractDecoratorPrivate *priv;
 	gchar *time_str;
+	gdouble elapsed = 0;
 
 	priv = TRACKER_EXTRACT_DECORATOR (decorator)->priv;
-	time_str = tracker_seconds_to_string ((gint) g_timer_elapsed (priv->timer, NULL), TRUE);
+	if (priv->timer) {
+		elapsed = g_timer_elapsed (priv->timer, NULL);
+		g_clear_pointer (&priv->timer, g_timer_destroy);
+	}
+
+	time_str = tracker_seconds_to_string (elapsed, TRUE);
 	g_message ("Extraction finished in %s", time_str);
-	g_timer_destroy (priv->timer);
-	priv->timer = NULL;
 	g_free (time_str);
 }
 
